// Implementazione del Client RMI

import java.rmi.*;
import java.io.*;

class Client {

	// Avvio del Client RMI
	public static void main(String[] args) {
		int registryPort = 1099;
		String registryHost = null;
		String serviceName = "Server";
		BufferedReader stdIn = new BufferedReader(new InputStreamReader(System.in));

		// Controllo dei parametri della riga di comando
		if (args.length != 1 && args.length != 2) {
			System.out.println("Sintassi: ClientFile NomeHost [registryPort]");
			System.exit(1);
		} else {
			registryHost = args[0];
			if (args.length == 2) {
				try {
					registryPort = Integer.parseInt(args[1]);
				} catch (Exception e) {
					System.out
							.println("Sintassi: ClientFile NomeHost [registryPort], registryPort intero");
					System.exit(2);
				}
			}
		}

		// Connessione al servizio RMI remoto
		try {
			String completeName = "//" + registryHost + ":" + registryPort + "/"
					+ serviceName;
			Server serverRMI = (Server) Naming.lookup(completeName);
			System.out.println("Client RMI: Servizio \"" + serviceName
					+ "\" connesso");

			System.out.println("\nRichieste di servizio fino a fine file");

			String service;
			System.out
					.print("Servizio (C=conta occorrenze, L=lista nomi file con carattere): ");

			while ((service = stdIn.readLine()) != null) {

				if (service.equals("C")) {

					String nomeFile;
					char c;
					System.out.print("Nome file? ");
					nomeFile = stdIn.readLine();
					System.out.print("Carattere? ");
					// Prendo il primo della linea
					c = stdIn.readLine().charAt(0);

					// Invocazione remota
					try {
						int occorrenze = serverRMI.conta_occorrenze(nomeFile, c);
						System.out.println("Il file " + nomeFile + " contiene "
								+ occorrenze + " occorrenze del carattere " + c + ".");
					} catch (RemoteException re) {
						System.out.println("Errore remoto: " + re.toString());
					}

				} // C

				else if (service.equals("L")) {
					String nomeDir;
					char c;
					System.out.print("Nome direttorio? ");
					nomeDir = stdIn.readLine();
					System.out.print("Carattere? ");
					// Prendo il primo della linea
					c = stdIn.readLine().charAt(0);

					String[] res;
					try {
						res = serverRMI.lista_file_car(nomeDir, c);
						System.out.println("Ecco i nomi dei file:");
						for(int i=0; i<res.length; i++)
							System.out.println(res[i]);						
					} catch (RemoteException re) {
						System.out.println("Errore remoto: " + re.toString());
					}
				} // L

				else
					System.out.println("Servizio non disponibile");

				System.out
						.print("Servizio (C=conta occorrenze, L=lista nomi file con carattere): ");
			} // !EOF

		} catch (Exception e) {
			System.err.println("ClientRMI: " + e.getMessage());
			e.printStackTrace();
			System.exit(1);
		}
	}
}