// Implementazione del Server

import java.io.BufferedReader;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileReader;
import java.rmi.Naming;
import java.rmi.RMISecurityManager;
import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;

public class ServerImpl extends UnicastRemoteObject implements Server {

	// Costruttore
	public ServerImpl() throws RemoteException {
		super();
	}

	// Conta le occorrenze di un carattere all'interno di un file
	public int conta_occorrenze(String file, char c) throws RemoteException {
		int cont = 0;
		File f = new File(file);
		if (!f.exists())
			throw new RemoteException("Il file: " + file + "non esiste.");
		FileInputStream is = null;
		try {
			is = new FileInputStream(file);
			// ciclo di lettura da sorgente e scrittura su destinazione
			int buffer = 0;
			// esco dal ciclo all lettura di un valore negativo -> EOF
			while ((buffer = is.read()) >= 0) {
				if (((char) buffer) == c)
					cont++;
			}
		} catch (Exception e) {
			throw new RemoteException(e.toString());
		}
		return cont;
	}

	// Restituisce la lista dei file il cui nome contiene car
	public String[] lista_file_car(String directory, char c)
			throws RemoteException {
		String[] temp;
		File f = new File(directory);
		if ((!f.exists()) || (!f.isDirectory()))
			throw new RemoteException("La directory: " + directory + " non esiste.");
		temp=f.list();
		int nomiFileDaRestituire=0;
		for(int i=0; i<temp.length; i++)
			if( temp[i].indexOf(c)!=-1 ) nomiFileDaRestituire++;
		String[] risultato = new String[nomiFileDaRestituire];
		// Uso la variabile come indice per riempire risultato
		nomiFileDaRestituire=0;
		for(int i=0; i<temp.length; i++)
			if( temp[i].indexOf(c)!=-1 ){
				risultato[nomiFileDaRestituire]=temp[i];
				nomiFileDaRestituire++;
			}
		return risultato;
	}

	// Avvio del Server RMI
	public static void main(String[] args) {

		int registryPort = 1099;
		String registryHost = "localhost";
		String serviceName = "Server";

		// Controllo dei parametri della riga di comando
		if (args.length != 0 && args.length != 1) {
			System.out.println("Sintassi: ServerImpl [registryPort]");
			System.exit(1);
		}
		if (args.length == 1) {
			try {
				registryPort = Integer.parseInt(args[0]);
			} catch (Exception e) {
				System.out
						.println("Sintassi: ServerImpl [registryPort], registryPort intero");
				System.exit(2);
			}
		}

		// Registrazione del servizio RMI
		String completeName = "//" + registryHost + ":" + registryPort + "/"
				+ serviceName;
		try {
			ServerImpl serverRMI = new ServerImpl();
			Naming.rebind(completeName, serverRMI);
			System.out.println("Server RMI: Servizio \"" + serviceName
					+ "\" registrato");
		} catch (Exception e) {
			System.err.println("Server RMI \"" + serviceName + "\": "
					+ e.getMessage());
			e.printStackTrace();
			System.exit(1);
		}
	}
}